//
//  ViewController.swift
//  Jacques
//
//  Created by Ope on 11/8/16.
//  Copyright © 2016 oooseun. All rights reserved.

//
import UIKit
import CoreBluetooth
import ChameleonFramework


class ViewController: UIViewController,BluetoothSerialDelegate {
    
    /// The peripherals that have been discovered (no duplicates and sorted by asc RSSI)
    var peripherals: [(peripheral: CBPeripheral, RSSI: Float)] = []
    
    @IBOutlet weak var connectedLabel: UILabel!
    override func viewDidLoad() {
        super.viewDidLoad()
        Chameleon.setGlobalThemeUsingPrimaryColor(FlatWhite(), withSecondaryColor:FlatRed() , andContentStyle: .contrast)
        
        // init serial
        serial = BluetoothSerial(delegate: self)
        serial.writeType = .withResponse
        serial.delegate = self
        
        // start scanning and schedule the time out
        serial.startScan()
        Timer.scheduledTimer(timeInterval: 10, target: self, selector: #selector(ViewController.scanTimeOut), userInfo: nil, repeats: false)
    }
    
    @IBAction func connectButton(_ sender: AnyObject) {
        
        if serial.centralManager.state != .poweredOn {
            let alert = UIAlertController(title: "Turn on Bluetooth", message: "Turn on Bluetooth to sync with Hydropal", preferredStyle: .alert)
            
            let OKAction = UIAlertAction(title: "OK", style: .default) { (action) in
            }
            
            alert.addAction(OKAction)
            
            self.present(alert, animated: true) {
            }
        } else {
            
            serial.startScan()
            Timer.scheduledTimer(timeInterval: 5, target: self, selector: #selector(ViewController.scanTimeOut), userInfo: nil, repeats: false)
        }
        
    }
    
    
    /// Should be called 10s after we've begun scanning
    func scanTimeOut() {
        // timeout has occurred, stop scanning and give the user the option to try again
        serial.stopScan()
    }
    
    //MARK: BluetoothSerialDelegate
    
    func serialDidDiscoverPeripheral(_ peripheral: CBPeripheral, RSSI: NSNumber?) {
        for existing in peripherals {
            if existing.peripheral.identifier == peripheral.identifier {
                serial.connectToPeripheral(existing.peripheral)
            }
        }
        serial.stopScan() //Can be problematic
        let theRSSI = RSSI?.floatValue ?? 0.0
        peripherals.append(peripheral: peripheral, RSSI: theRSSI)
        peripherals.sort { $0.RSSI < $1.RSSI }
        
    }
    
    func serialDidFailToConnect(_ peripheral: CBPeripheral, error: NSError?) {
        
    }
    
    func serialDidDisconnect(_ peripheral: CBPeripheral, error: NSError?) {
        connectedLabel.text = "NC"
        
    }
    
    func serialDidConnect(_ peripheral: CBPeripheral) {
        connectedLabel.text = "C"
        print("Connected to ",peripheral.name ?? "Bluetooth device")
    }
    
    
    func serialIsReady(_ peripheral: CBPeripheral) {
        
    }
    
    func serialDidChangeState(central:CBCentralManager) {
        if central.state == .poweredOn{
            print("Bluetooth ON")
            serial.startScan()
            Timer.scheduledTimer(timeInterval: 5, target: self, selector: #selector(ViewController.scanTimeOut), userInfo: nil, repeats: false)
            
            
            
        }
    }
    
    
}


